@@ -185,12 +185,9 @@ print(struct command *cmd)	/* print on screen */
             *s = ' ';
             s++;
         }
-        if (!myformat(s, q->value, p->pointer, r ? r->pointer : NULL)) {
-            sprintf(string, "'%s' is not a valid format",
-                    (char *)p->pointer);
-            error (sERROR, string);
-            break;
-        }
+        if (!myformat(s, INBUFFLEN, q->value, p->pointer, r ? r->pointer : NULL)) {
+	    break;
+	}
         onestring(string);
         break;
     case 's':
@@ -599,7 +596,7 @@ static void decode_key(int key, char *to) /* decode keycode into string */
 
 
 char *
-replace(char *string)		/* replace \n,\a, etc. */
+replace_escapes(char *string)		/* replace \n,\a, etc. */
 {
     char *from, *to;
     char *p;
